/hg/gfx-test: * src/org/gfxtest/testsuites/PrintTestArcs.java:

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Fri Jun 22 03:20:59 PDT 2012


changeset bfdafdcfe4b2 in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=bfdafdcfe4b2
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Fri Jun 22 12:23:29 2012 +0200

	* src/org/gfxtest/testsuites/PrintTestArcs.java:
	  Added new tests to this test suite.
	* src/org/gfxtest/testsuites/PrintTestColorPaint.java:
	  Added new tests to this test suite.
	* src/org/gfxtest/testsuites/PrintTestLines.java:
	  Minor fix - removed unused import.


diffstat:

 ChangeLog                                           |    9 +
 src/org/gfxtest/testsuites/PrintTestArcs.java       |  176 +++++++++++++++++--
 src/org/gfxtest/testsuites/PrintTestColorPaint.java |  180 ++++++++++++++++---
 src/org/gfxtest/testsuites/PrintTestLines.java      |    1 -
 4 files changed, 309 insertions(+), 57 deletions(-)

diffs (truncated from 558 to 500 lines):

diff -r 044287479944 -r bfdafdcfe4b2 ChangeLog
--- a/ChangeLog	Thu Jun 21 14:38:56 2012 +0200
+++ b/ChangeLog	Fri Jun 22 12:23:29 2012 +0200
@@ -1,3 +1,12 @@
+2012-06-22  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/PrintTestArcs.java:
+	Added new tests to this test suite.
+	* src/org/gfxtest/testsuites/PrintTestColorPaint.java:
+	Added new tests to this test suite.
+	* src/org/gfxtest/testsuites/PrintTestLines.java:
+	Minor fix - removed unused import.
+
 2012-06-21  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/PrintTestSlopedLines.java:
diff -r 044287479944 -r bfdafdcfe4b2 src/org/gfxtest/testsuites/PrintTestArcs.java
--- a/src/org/gfxtest/testsuites/PrintTestArcs.java	Thu Jun 21 14:38:56 2012 +0200
+++ b/src/org/gfxtest/testsuites/PrintTestArcs.java	Fri Jun 22 12:23:29 2012 +0200
@@ -127,7 +127,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Color of all rendered arcs are set to black.
      *
      * @param image
@@ -156,7 +156,141 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
+     * Arc color are selected from a palette.
+     *
+     * @param image
+     *            image to which arcs are to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testDrawArcColorPalette(TestImage image, Graphics2D graphics2d)
+    {
+        drawArcs(image, graphics2d, ARC_RADIUS_STEP, new CommonArcDrawCallbacks()
+        {
+            /**
+             * Callback function called before each arc is rendered.
+             */
+            @Override
+            public void iterationCallBack(int x, int y, int radius, int maxRadius, int index)
+            {
+                // set arc color
+                this.graphics.setColor(ColorPalette.getColor(index));
+                return;
+            }
+        });
+
+        // test return value
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Test basic behavior of method Graphics.drawArc().
+     * Arc color are selected from a palette.
+     *
+     * @param image
+     *            image to which arcs are to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testDrawArcColorPaletteInv(TestImage image, Graphics2D graphics2d)
+    {
+        drawArcs(image, graphics2d, ARC_RADIUS_STEP, new CommonArcDrawCallbacks()
+        {
+            /**
+             * Callback function called before each arc is rendered.
+             */
+            @Override
+            public void iterationCallBack(int x, int y, int radius, int maxRadius, int index)
+            {
+                // set arc color
+                this.graphics.setColor(ColorPalette.getColor(MAX_COLOR_INDEX - index));
+                return;
+            }
+        });
+
+        // test return value
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Test basic behavior of method Graphics.drawArc().
+     * Arc color are selected from a grayscale palette.
+     *
+     * @param image
+     *            image to which arcs are to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testDrawArcGrayScale(TestImage image, Graphics2D graphics2d)
+    {
+        drawArcs(image, graphics2d, ARC_RADIUS_STEP, new CommonArcDrawCallbacks()
+        {
+            /**
+             * Callback function called before each arc is rendered.
+             */
+            @Override
+            public void iterationCallBack(int x, int y, int radius, int maxRadius, int index)
+            {
+                // compute grayscale value
+                float gray = radius * 1.0f / maxRadius;
+                // clamp the grayscale value
+                if (gray > 1.0f)
+                {
+                    gray = 1.0f;
+                }
+                // set arc color
+                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
+                return;
+            }
+        });
+
+        // test return value
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Test basic behavior of method Graphics.drawArc().
+     * Arc color are selected from a grayscale palette.
+     *
+     * @param image
+     *            image to which arcs are to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @return test result status - PASSED, FAILED or ERROR
+     */
+    public TestResult testDrawArcGrayScaleInv(TestImage image, Graphics2D graphics2d)
+    {
+        drawArcs(image, graphics2d, ARC_RADIUS_STEP, new CommonArcDrawCallbacks()
+        {
+            /**
+             * Callback function called before each arc is rendered.
+             */
+            @Override
+            public void iterationCallBack(int x, int y, int radius, int maxRadius, int index)
+            {
+                // compute grayscale value
+                float gray = 1.0f - radius * 1.0f / maxRadius;
+                // clamp the grayscale value
+                if (gray < 0.0f)
+                {
+                    gray = 0.0f;
+                }
+                // set arc color
+                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
+                return;
+            }
+        });
+
+        // test return value
+        return TestResult.PASSED;
+    }
+
+    /**
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and default end caps.
      * Color of all rendered arcs are set to black.
      *
@@ -203,7 +337,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_BUTT.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -251,7 +385,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_ROUND.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -299,7 +433,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_SQUARE.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -347,7 +481,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_BUTT.
      * Join style is set to miter style.
      * Color of all rendered arcs are set to black.
@@ -395,7 +529,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_ROUND.
      * Join style is set to miter style.
      * Color of all rendered arcs are set to black.
@@ -443,7 +577,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_SQUARE.
      * Join style is set to miter style.
      * Color of all rendered arcs are set to black.
@@ -491,7 +625,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_BUTT.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -539,7 +673,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_ROUND.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -587,7 +721,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_SQUARE.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -635,7 +769,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and default end caps.
      * Color of all rendered arcs are set to black.
      *
@@ -687,7 +821,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_BUTT.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -740,7 +874,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_ROUND.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -793,7 +927,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_SQUARE.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -846,7 +980,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_BUTT.
      * Join style is set to miter style.
      * Color of all rendered arcs are set to black.
@@ -899,7 +1033,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_ROUND.
      * Join style is set to miter style.
      * Color of all rendered arcs are set to black.
@@ -952,7 +1086,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_SQUARE.
      * Join style is set to miter style.
      * Color of all rendered arcs are set to black.
@@ -1005,7 +1139,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_BUTT.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -1058,7 +1192,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_ROUND.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
@@ -1111,7 +1245,7 @@
     }
 
     /**
-     * Test basic behavior of method Graphics.drawOval().
+     * Test basic behavior of method Graphics.drawArc().
      * Arcs are rendered with various width and end caps set to CAP_SQUARE.
      * Join style is set to bevel style.
      * Color of all rendered arcs are set to black.
diff -r 044287479944 -r bfdafdcfe4b2 src/org/gfxtest/testsuites/PrintTestColorPaint.java
--- a/src/org/gfxtest/testsuites/PrintTestColorPaint.java	Thu Jun 21 14:38:56 2012 +0200
+++ b/src/org/gfxtest/testsuites/PrintTestColorPaint.java	Fri Jun 22 12:23:29 2012 +0200
@@ -227,6 +227,102 @@
     }
 
     /**
+     * Method which renders set of circles using various colors and
+     * stroke styles. For each circle, the callback function/method is called to
+     * perform all required setup.
+     * 
+     * @param image
+     *            image to which circles are to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @param radiusStep
+     *            between two near circles
+     * @param circleDrawCallback
+     *            class containing set of callback methods
+     */
+    private void drawCircle(TestImage image, Graphics2D graphics2d, int radiusStep, CommonCircleDrawCallbacks circleDrawCallback)
+    {
+        // setup rendering
+        circleDrawCallback.setup(image, graphics2d);
+
+        // image width and height
+        final int width = image.getWidth();
+        final int height = image.getHeight();
+
+        // horizontal coordinates of circle center
+        final int xc = width >> 1;
+        final int yc = height >> 1;
+
+        // maximum radius
+        final int maxRadius = Math.min(width, height) - BORDER;
+
+        // index to color palette
+        int colorIndex = 0;
+
+        // draw all circles onto a paper
+        for (int radius = MINIMUM_RADIUS; radius < maxRadius; radius += radiusStep)
+        {
+            // setup can be made for each circle
+            circleDrawCallback.iterationCallBack(xc, yc, radius, maxRadius, colorIndex++);
+            // render the circle
+            graphics2d.drawOval(xc - radius, yc - radius, radius << 1, radius << 1);
+        }
+
+        // cleanup rendering
+        circleDrawCallback.cleanup();
+    }
+
+    /**
+     * Method which renders set of arcs using various colors and
+     * stroke styles. For each arc, the callback function/method is called to
+     * perform all required setup.
+     * 
+     * @param image
+     *            image to which arcs are to be drawn
+     * @param graphics2d
+     *            graphics canvas
+     * @param radiusStep
+     *            between two near arcs
+     * @param arcDrawCallback
+     *            class containing set of callback methods
+     */
+    private void drawArcs(TestImage image, Graphics2D graphics2d, int radiusStep, CommonArcDrawCallbacks arcDrawCallback)
+    {
+        // setup rendering
+        arcDrawCallback.setup(image, graphics2d);
+
+        // image width and height
+        final int width = image.getWidth();
+        final int height = image.getHeight();
+
+        // horizontal coordinates of arc center
+        final int xc = width >> 1;
+        final int yc = height >> 1;
+
+        // maximum radius
+        final int maxRadius = Math.min(width, height) - BORDER;
+
+        // index to color palette
+        int colorIndex = 0;
+
+        // arc start angle
+        int startAngle = 0;
+
+        // draw all arcs onto a paper
+        for (int radius = MINIMUM_RADIUS; radius < maxRadius; radius += radiusStep)
+        {
+            // setup can be made for each arc
+            arcDrawCallback.iterationCallBack(xc, yc, radius, maxRadius, colorIndex++);
+            startAngle += 4;
+            // render the arc
+            graphics2d.drawArc(xc - radius, yc - radius, radius << 1, radius << 1, startAngle, 270);
+        }
+
+        // cleanup rendering
+        arcDrawCallback.cleanup();
+    }
+
+    /**
      * Test basic behavior of method Graphics.drawLine().
      * Horizontal lines are rendered with default width and default end caps.
      * Lines color are selected from a palette.
@@ -380,49 +476,63 @@
     }
 
     /**
-     * Method which renders set of circles using various colors and
-     * stroke styles. For each circle, the callback function/method is called to
-     * perform all required setup.
-     * 
+     * Test basic behavior of method Graphics.drawArc().
+     * Arc color are selected from a palette.
+     *
      * @param image
      *            image to which circles are to be drawn
      * @param graphics2d
      *            graphics canvas
-     * @param radiusStep
-     *            between two near circles
-     * @param circleDrawCallback
-     *            class containing set of callback methods
+     * @return test result status - PASSED, FAILED or ERROR
      */
-    private void drawCircle(TestImage image, Graphics2D graphics2d, int radiusStep, CommonCircleDrawCallbacks circleDrawCallback)
+    public TestResult testDrawArcColorPalette(TestImage image, Graphics2D graphics2d)
     {
-        // setup rendering
-        circleDrawCallback.setup(image, graphics2d);
+        drawArcs(image, graphics2d, ARC_RADIUS_STEP, new CommonArcDrawCallbacks()
+        {
+            /**
+             * Callback function called before each arc is rendered.
+             */
+            @Override
+            public void iterationCallBack(int x, int y, int radius, int maxRadius, int index)
+            {
+                // set arc color
+                this.graphics.setColor(ColorPalette.getColor(index));
+                return;
+            }
+        });
 
-        // image width and height
-        final int width = image.getWidth();
-        final int height = image.getHeight();
+        // test return value
+        return TestResult.PASSED;
+    }
 
-        // horizontal coordinates of circle center
-        final int xc = width >> 1;
-        final int yc = height >> 1;
+    /**
@@ -380,49 +476,63 @@
      * @param image
-     *            image to which circles are to be drawn
+     *            image to which arcs are to be drawn
      * @param graphics2d
      *            graphics canvas



More information about the distro-pkg-dev mailing list